remove 'get' prefix in methods
diff --git a/openstack/storage/v1/containers/urls.go b/openstack/storage/v1/containers/urls.go
index 4084bcc..2a06f95 100644
--- a/openstack/storage/v1/containers/urls.go
+++ b/openstack/storage/v1/containers/urls.go
@@ -2,12 +2,12 @@
 
 import "github.com/rackspace/gophercloud"
 
-// getAccountURL returns the URI used to list Containers.
-func getAccountURL(c *gophercloud.ServiceClient) string {
+// accountURL returns the URI used to list Containers.
+func accountURL(c *gophercloud.ServiceClient) string {
 	return c.Endpoint
 }
 
-// getContainerURL returns the URI for making Container requests.
-func getContainerURL(c *gophercloud.ServiceClient, container string) string {
+// containerURL returns the URI for making Container requests.
+func containerURL(c *gophercloud.ServiceClient, container string) string {
 	return c.ServiceURL(container)
 }